User rank styles
================

Misago user ranks allow you to specify their css class when editing them in admin control panel.

This class is then used to build proper css class names used around the UI. Assuming that you'll enter `mvp` in this field, you'll be able to define following css clases to customise how user's belonging to this rank are presented:

- `list-group-rank-mvp` class will be added to rows in user rankings with users with this rank.
- `page-header-rank-mvp` class will be added to page header on profiles of users with this rank.
- `post-mvp` class will be added to posts made by users with this rank.
- `user-card-mvp` class will be added to user cards presenting users with this rank.


## Default classes

Misago's default theme defines following basic classes, visualised as colorful borders and title colors:

- `primary`
- `success`
- `warning`
- `danger`
